#!/usr/bin/python


import sys
sys.path.insert(0,"../")

import apt
import unittest
import os
import xapian
from softwarecenter.enums import XAPIAN_VALUE_PKGNAME
from softwarecenter.db.update import rebuild_database

class testXapian(unittest.TestCase):
    """ tests the xapian database """

    def setUp(self):
        # FIXME: create a fixture DB instead of using the system one
        # but for now that does not matter that much, only if we
        # call open the db is actually read and the path checked
        pathname = "../data/xapian"
        if not os.listdir(pathname):
            rebuild_database(pathname)
        self.xapiandb = xapian.Database(pathname)
        self.enquire = xapian.Enquire(self.xapiandb)

    def test_exact_query(self):
        query = xapian.Query("APsoftware-center")
        self.enquire.set_query(query)
        matches = self.enquire.get_mset(0, 100)
        self.assertEqual(len(matches), 1)

    def test_search_term(self):
        search_term = "apt"
        parser = xapian.QueryParser()
        query = parser.parse_query(search_term)
        self.enquire.set_query(query)
        matches = self.enquire.get_mset(0, 100)
        self.assertTrue(len(matches) > 5)

    def test_category_query(self):
        query = xapian.Query("ACaudiovideo")
        self.enquire.set_query(query)
        matches = self.enquire.get_mset(0, 100)
        self.assertTrue(len(matches) > 5)

    def test_mime_query(self):
        query = xapian.Query("AMtext/html")
        self.enquire.set_query(query)
        matches = self.enquire.get_mset(0, 100)
        self.assertTrue(len(matches) > 5)
        pkgs = set()
        for match in matches:
            doc = match.get_document()
            pkgs.add(doc.get_value(XAPIAN_VALUE_PKGNAME))
        self.assertTrue("firefox" in pkgs)

if __name__ == "__main__":
    import logging
    logging.basicConfig(level=logging.DEBUG)
    unittest.main()
